@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 4365 2008-11-24 15:30:25Z wwalker $"
-__version__   = "$Revision: 4365 $"
-__date__      = "$Date: 2008-11-24 10:30:25 -0500 (Mon, 24 Nov 2008) $"
+__id__        = "$Id: gnomespeechfactory.py 4452 2009-01-22 00:34:51Z wwalker $"
+__version__   = "$Revision: 4452 $"
+__date__      = "$Date: 2009-01-21 19:34:51 -0500 (Wed, 21 Jan 2009) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -705,7 +705,10 @@ class SpeechServer(speechserver.SpeechServer):
                      used to augment/override the default
                      voice settings.
         """
-        self.speak(chnames.getCharacterName(character), acss)
+        chname = chnames.getCharacterName(character)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            chname = orca_state.activeScript.adjustForPronunciation(chname)
+        self.speak(chname, acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
         """Speaks the given list of utterances immediately.
