@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4365 2008-11-24 15:30:25Z wwalker $"
-__version__   = "$Revision: 4365 $"
-__date__      = "$Date: 2008-11-24 10:30:25 -0500 (Mon, 24 Nov 2008) $"
+__id__        = "$Id: settings.py 4508 2009-02-08 19:40:32Z wwalker $"
+__version__   = "$Revision: 4508 $"
+__date__      = "$Date: 2009-02-08 14:40:32 -0500 (Sun, 08 Feb 2009) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -713,6 +713,30 @@ textAttributesBrailleIndicator = TEXT_ATTR_BRAILLE_NONE
 #
 repeatCharacterLimit = 4
 
+# Tags associated with ARIA landmarks.
+#
+ariaLandmarks = [
+    "application",
+    "article",
+    "banner",
+    "complementary",
+    "contentinfo",
+    "definition",
+    "directory",
+    "document",
+    "grid",
+    "log",
+    "main",
+    "menubar",
+    "navigation",
+    "note",
+    "region",
+    "search",
+    "secondary",
+    "seealso",
+    "status",
+]
+
 # Script developer feature.  If False, just the default script
 # will be used.  Helps determine difference between custom
 # scripts and the default script behavior.
@@ -1000,6 +1024,15 @@ setScriptMapping(re.compile(_('Bon Echo')), "Mozilla")
 #
 setScriptMapping(re.compile(_('Minefield')), "Mozilla")
 
+# Translators: see the regular expression note above.  This is for a
+# version of Mozilla Firefox, which chooses to create strange names
+# for itself at the drop of a hat. [[[TODO - JD: Not marked for
+# translation due to string freeze. I'm not convinced it needs to
+# be translated either.]]]
+#
+#setScriptMapping(re.compile(_('Shiretoko')), "Mozilla")
+setScriptMapping(re.compile('Shiretoko'), "Mozilla")
+
 # This is a temporary fix for the schema/FF 3.0 not being accessible
 # issue. (See GNOME bugs #535827 and #555466.)
 #
